@@ -184,7 +184,7 @@ class Tokenizer(tokenization_abc.Tokenization):
                     result[ngram] = 0
 
         # sorted by len: first we replace the longer n-grams, then shorter ones.
-        result = sorted(result.items(), key=lambda x: len(x[0]), reverse=True)
+        result = dict(sorted(result.items(), key=lambda x: len(x[0]), reverse=True))
 
         # updates doc: replaces n-grams with tokens
         for doc in self.docs:
